@@ -11,8 +11,8 @@ class AxAlgoWrapper():
     def __init__(self):
         self.algorithm = None
     def create(self, metric, mode, search_space, **args):
-        ax_client = AxClient(enforce_sequential_optimization=False, verbose_logging = True)
-        search_space = AxSpace(search_space).search_space
+        ax_client = AxClient(enforce_sequential_optimization=False, verbose_logging=True)
+        search_space = AxSpace(search_space).get_search_space()
 
         if mode == 'max':
             minimize = False
