@@ -78,8 +78,6 @@ class GridHandler():
         print('INFO: Submitting {} idds grid job(s)'.format(n_jobs))
         with tempfile.TemporaryDirectory() as tmpdirname:
             idds_config, search_space = transpose_config(config)
-            from pdb import set_trace
-            set_trace()
             idds_config_path = os.path.join(tmpdirname, 'idds_config.json')
             search_space_path = os.path.join(tmpdirname, 'search_space.json')
             # create temporary files for idds configuration and search space
