@@ -76,15 +76,15 @@ class JobBuilder():
         if value not in kMetricMode:
             raise ValueError('metric mode must be either "min" or "max"')
         self._mode = value
-        
-    @property
-    def resource_per_trial(self):
-        return self._resource_per_trial
     
     @property
     def resource(self):
         return self._resource
     
+    @property
+    def resource_per_trial(self):
+        return self._resource_per_trial
+    
     @resource_per_trial.setter
     def resource_per_trial(self, value):
         resource = JobBuilder.get_resource_info()
@@ -105,7 +105,29 @@ class JobBuilder():
         print('INFO: Each trial will use {} CPU(s) resource'.format(resource_per_trial['cpu']))
         self._resource_per_trial = resource_per_trial
         self._resource = resource
-
+    
+    @property
+    def algorithm_param(self):
+        return self._algorithm_param
+    @property
+    def scheduler_param(self):
+        return self._scheduler_param
+    
+    @algorithm_param.setter
+    def algorithm_param(self, val):
+        self._algorithm_param = val if val is not None else {}
+            
+    @scheduler_param.setter
+    def scheduler_param(self, val):
+        self._scheduler_param = val if val is not None else {}
+        
+    @property
+    def stop(self):
+        return self._stop
+    
+    @stop.setter
+    def stop(self, val):
+        self._stop = val if val is not None else {}
         
     @property
     def df(self) -> 'pandas.DataFrame':
